# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import session_status_pb2 as session__status__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14session_status.proto\x1a\x14sort_direction.proto\"\xbc\x02\n\nSessionRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12\x15\n\rpartition_ids\x18\x03 \x03(\t\x12\x31\n\x07options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\"S\n\x0fSessionRawField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.SessionRawEnumField\"S\n\x0fTaskOptionField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.TaskOptionEnumField\"\'\n\x16TaskOptionGenericField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\x8a\x02\n\x0cSessionField\x12J\n\x11session_raw_field\x18\x01 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.SessionRawFieldH\x00\x12J\n\x11task_option_field\x18\x02 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.TaskOptionFieldH\x00\x12Y\n\x19task_option_generic_field\x18\x03 \x01(\x0b\x32\x34.armonik.api.grpc.v1.sessions.TaskOptionGenericFieldH\x00\x42\x07\n\x05\x66ield\"\xd6\x05\n\x13ListSessionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12H\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x38.armonik.api.grpc.v1.sessions.ListSessionsRequest.Filter\x12\x44\n\x04sort\x18\x04 \x01(\x0b\x32\x36.armonik.api.grpc.v1.sessions.ListSessionsRequest.Sort\x12\x19\n\x11with_task_options\x18\x05 \x01(\x08\x1a\xe8\x02\n\x06\x46ilter\x12\x18\n\x10\x61pplication_name\x18\x01 \x01(\t\x12\x1b\n\x13\x61pplication_version\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x31\n\rcreated_after\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63\x61ncelled_after\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10\x63\x61ncelled_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x08 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x1a\x87\x01\n\x04Sort\x12\x39\n\x05\x66ield\x18\x01 \x01(\x0b\x32*.armonik.api.grpc.v1.sessions.SessionField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x82\x01\n\x14ListSessionsResponse\x12:\n\x08sessions\x18\x01 \x03(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\'\n\x11GetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"O\n\x12GetSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14\x43\x61ncelSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15\x43\x61ncelSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"/\n\x19\x43ountTasksByStatusRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"N\n\x1a\x43ountTasksByStatusResponse\x12\x30\n\x06status\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount*\xca\x02\n\x13SessionRawEnumField\x12&\n\"SESSION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12%\n!SESSION_RAW_ENUM_FIELD_SESSION_ID\x10\x01\x12!\n\x1dSESSION_RAW_ENUM_FIELD_STATUS\x10\x02\x12(\n$SESSION_RAW_ENUM_FIELD_PARTITION_IDS\x10\x03\x12\"\n\x1eSESSION_RAW_ENUM_FIELD_OPTIONS\x10\x04\x12%\n!SESSION_RAW_ENUM_FIELD_CREATED_AT\x10\x05\x12\'\n#SESSION_RAW_ENUM_FIELD_CANCELLED_AT\x10\x06\x12#\n\x1fSESSION_RAW_ENUM_FIELD_DURATION\x10\x07*\xc3\x03\n\x13TaskOptionEnumField\x12&\n\"TASK_OPTION_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\'\n#TASK_OPTION_ENUM_FIELD_MAX_DURATION\x10\x01\x12&\n\"TASK_OPTION_ENUM_FIELD_MAX_RETRIES\x10\x02\x12#\n\x1fTASK_OPTION_ENUM_FIELD_PRIORITY\x10\x03\x12\'\n#TASK_OPTION_ENUM_FIELD_PARTITION_ID\x10\x04\x12+\n\'TASK_OPTION_ENUM_FIELD_APPLICATION_NAME\x10\x05\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_VERSION\x10\x06\x12\x30\n,TASK_OPTION_ENUM_FIELD_APPLICATION_NAMESPACE\x10\x07\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_SERVICE\x10\x08\x12&\n\"TASK_OPTION_ENUM_FIELD_ENGINE_TYPE\x10\tB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONRAWENUMFIELD']._serialized_start=2220
  _globals['_SESSIONRAWENUMFIELD']._serialized_end=2550
  _globals['_TASKOPTIONENUMFIELD']._serialized_start=2553
  _globals['_TASKOPTIONENUMFIELD']._serialized_end=3004
  _globals['_SESSIONRAW']._serialized_start=180
  _globals['_SESSIONRAW']._serialized_end=496
  _globals['_SESSIONRAWFIELD']._serialized_start=498
  _globals['_SESSIONRAWFIELD']._serialized_end=581
  _globals['_TASKOPTIONFIELD']._serialized_start=583
  _globals['_TASKOPTIONFIELD']._serialized_end=666
  _globals['_TASKOPTIONGENERICFIELD']._serialized_start=668
  _globals['_TASKOPTIONGENERICFIELD']._serialized_end=707
  _globals['_SESSIONFIELD']._serialized_start=710
  _globals['_SESSIONFIELD']._serialized_end=976
  _globals['_LISTSESSIONSREQUEST']._serialized_start=979
  _globals['_LISTSESSIONSREQUEST']._serialized_end=1705
  _globals['_LISTSESSIONSREQUEST_FILTER']._serialized_start=1207
  _globals['_LISTSESSIONSREQUEST_FILTER']._serialized_end=1567
  _globals['_LISTSESSIONSREQUEST_SORT']._serialized_start=1570
  _globals['_LISTSESSIONSREQUEST_SORT']._serialized_end=1705
  _globals['_LISTSESSIONSRESPONSE']._serialized_start=1708
  _globals['_LISTSESSIONSRESPONSE']._serialized_end=1838
  _globals['_GETSESSIONREQUEST']._serialized_start=1840
  _globals['_GETSESSIONREQUEST']._serialized_end=1879
  _globals['_GETSESSIONRESPONSE']._serialized_start=1881
  _globals['_GETSESSIONRESPONSE']._serialized_end=1960
  _globals['_CANCELSESSIONREQUEST']._serialized_start=1962
  _globals['_CANCELSESSIONREQUEST']._serialized_end=2004
  _globals['_CANCELSESSIONRESPONSE']._serialized_start=2006
  _globals['_CANCELSESSIONRESPONSE']._serialized_end=2088
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_start=2090
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_end=2137
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_start=2139
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_end=2217
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import objects_pb2 as objects__pb2
from ..common import worker_common_pb2 as worker__common__pb2


class WorkerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Process = channel.stream_unary(
                '/armonik.api.grpc.v1.worker.Worker/Process',
                request_serializer=worker__common__pb2.ProcessRequest.SerializeToString,
                response_deserializer=worker__common__pb2.ProcessReply.FromString,
                )
        self.HealthCheck = channel.unary_unary(
                '/armonik.api.grpc.v1.worker.Worker/HealthCheck',
                request_serializer=objects__pb2.Empty.SerializeToString,
                response_deserializer=worker__common__pb2.HealthCheckReply.FromString,
                )


class WorkerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Process(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Process': grpc.stream_unary_rpc_method_handler(
                    servicer.Process,
                    request_deserializer=worker__common__pb2.ProcessRequest.FromString,
                    response_serializer=worker__common__pb2.ProcessReply.SerializeToString,
            ),
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=objects__pb2.Empty.FromString,
                    response_serializer=worker__common__pb2.HealthCheckReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.worker.Worker', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Worker(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Process(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/armonik.api.grpc.v1.worker.Worker/Process',
            worker__common__pb2.ProcessRequest.SerializeToString,
            worker__common__pb2.ProcessReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.worker.Worker/HealthCheck',
            objects__pb2.Empty.SerializeToString,
            worker__common__pb2.HealthCheckReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import partitions_common_pb2 as partitions__common__pb2


class PartitionsStub(object):
    """*
    The PartitionsService provides methods to manage partitions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPartitions = channel.unary_unary(
                '/armonik.api.grpc.v1.partitions.Partitions/ListPartitions',
                request_serializer=partitions__common__pb2.ListPartitionsRequest.SerializeToString,
                response_deserializer=partitions__common__pb2.ListPartitionsResponse.FromString,
                )
        self.GetPartition = channel.unary_unary(
                '/armonik.api.grpc.v1.partitions.Partitions/GetPartition',
                request_serializer=partitions__common__pb2.GetPartitionRequest.SerializeToString,
                response_deserializer=partitions__common__pb2.GetPartitionResponse.FromString,
                )


class PartitionsServicer(object):
    """*
    The PartitionsService provides methods to manage partitions.
    """

    def ListPartitions(self, request, context):
        """*
        Get a partitions list using pagination, filters and sorting.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPartition(self, request, context):
        """*
        Get a partition by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PartitionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPartitions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartitions,
                    request_deserializer=partitions__common__pb2.ListPartitionsRequest.FromString,
                    response_serializer=partitions__common__pb2.ListPartitionsResponse.SerializeToString,
            ),
            'GetPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPartition,
                    request_deserializer=partitions__common__pb2.GetPartitionRequest.FromString,
                    response_serializer=partitions__common__pb2.GetPartitionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.partitions.Partitions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Partitions(object):
    """*
    The PartitionsService provides methods to manage partitions.
    """

    @staticmethod
    def ListPartitions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.partitions.Partitions/ListPartitions',
            partitions__common__pb2.ListPartitionsRequest.SerializeToString,
            partitions__common__pb2.ListPartitionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.partitions.Partitions/GetPartition',
            partitions__common__pb2.GetPartitionRequest.SerializeToString,
            partitions__common__pb2.GetPartitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
